package me.yoqi.android.appmanager.views;

import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.Context;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import java.util.List;

import me.yoqi.android.appmanager.R;
import me.yoqi.android.appmanager.model.AppInfo;
import me.yoqi.android.utils.SimplexToast;

/**
 * appinfo数据适配器
 *
 * @author liuyuqi.gov@msn.cn
 * @createTime 2020-10-01
 */
public class AppInfoAdapter extends BaseAdapter {

    private List<AppInfo> mlistAppinfo = null;
    LayoutInflater infater = null;
    Context mContext;

    public AppInfoAdapter(Context context, List<AppInfo> apps) {
        mContext = context;
        infater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        mlistAppinfo = apps;
    }

    @Override
    public int getCount() {
        return mlistAppinfo.size();
    }

    @Override
    public Object getItem(int position) {
        return mlistAppinfo.get(position);
    }

    @Override
    public long getItemId(int position) {
        return 0;
    }

    @Override
    public View getView(int position, View convertview, ViewGroup arg2) {
        View view = null;
        ViewHolder holder = null;
        if (convertview == null || convertview.getTag() == null) {
            view = infater.inflate(R.layout.lv_item, null); //设置布局
            holder = new ViewHolder(view);
            view.setTag(holder);
        } else {
            view = convertview;
            holder = (ViewHolder) convertview.getTag();
        }
        final AppInfo Appinfo = (AppInfo) getItem(position);
        holder.icon.setImageDrawable(Appinfo.getAppIcon());
        holder.appNmae.setText(Appinfo.getAppName());
        holder.packageName.setText("包名：" + Appinfo.getPackageName());
        if (!TextUtils.isEmpty(Appinfo.getLuancherActivity())) {
            holder.launcherName.setText("启动类名：" + Appinfo.getLuancherActivity());
        }
        view.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                SimplexToast.show(mContext, "包名已复制到剪切板");
                //获取剪贴板管理器：
                ClipboardManager cm = (ClipboardManager) mContext.getSystemService(Context.CLIPBOARD_SERVICE);
                // 创建普通字符型ClipData
                ClipData mClipData = ClipData.newPlainText("Label", Appinfo.getPackageName());
                // 将ClipData内容放到系统剪贴板里。
                cm.setPrimaryClip(mClipData);
            }
        });
        return view;
    }

    static class ViewHolder {
        ImageView icon;
        TextView appNmae;
        TextView packageName;
        TextView launcherName;

        public ViewHolder(View view) {
            this.icon = (ImageView) view.findViewById(R.id.icon);
            this.appNmae = (TextView) view.findViewById(R.id.appNmae);
            this.packageName = (TextView) view.findViewById(R.id.packageName);
            this.launcherName = (TextView) view.findViewById(R.id.launcherName);
        }
    }
}
